@@ -7,6 +7,8 @@ from os.path import expanduser
 from . import routes
 from autoprotocol import Protocol
 import requests
+from .version import __version__
+import platform
 
 
 class Connection(object):
@@ -77,9 +79,15 @@ class Connection(object):
             "X-User-Email": email,
             "X-User-Token": token,
             "Content-Type": "application/json",
-            "Accept": "application/json"
+            "Accept": "application/json",
+            "User-Agent": "txpy/{} ({}/{}; {}/{}; {}; {})".format(__version__,
+                                                                  platform.python_implementation(),
+                                                                  platform.python_version(),
+                                                                  platform.system(),
+                                                                  platform.release(),
+                                                                  platform.machine(),
+                                                                  platform.architecture()[0])
         }
-
         # Preload known environment arguments
         self.env_args = dict(api_root=self.api_root, org_id=self.organization_id)
         transcriptic.api = self
@@ -126,6 +134,17 @@ class Connection(object):
                              'default': lambda resp: Exception("cannot preview protocol.")
                          })
 
+    def organizations(self):
+        """Get list of organizations"""
+        route = self.get_route('get_organizations')
+        return self.get(route)
+
+    def get_organization(self, org_id=None):
+        """Get particular organization"""
+        route = self.get_route('get_organization', org_id=org_id)
+        resp = self.get(route, status_response={'200': lambda resp: resp, 'default': lambda resp: resp})
+        return resp
+
     def projects(self):
         """Get list of projects in organization"""
         route = self.get_route('get_projects')
@@ -150,7 +169,7 @@ class Connection(object):
         """Get list of runs in project"""
         route = self.get_route('get_project_runs', project_id=project_id)
         return self.get(route, status_response={
-            "200": lambda resp: resp.json()["runs"],
+            "200": lambda resp: resp.json(),
             "default": lambda resp: RuntimeError(
                 "There was an error fetching the runs in project %s" %
                 project_id
